==> sdd.fiservapi.client-0.1.12-sources.jar: ar/com/sdd/fiservapi/io/PaymentTokenSaleTransactionRequest.java <==
package ar.com.sdd.fiservapi.io;

import ar.com.sdd.fiservapi.io.secure3d.AuthenticationRequest;
import ar.com.sdd.fiservapi.model.Order;
import ar.com.sdd.fiservapi.model.StoredCredentials;
import ar.com.sdd.fiservapi.model.TransactionAmount;
import ar.com.sdd.fiservapi.model.token.PaymentMethod;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.Serializable;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class PaymentTokenSaleTransactionRequest implements Serializable {

    @JsonProperty("ipgTransactionId")
    private Long ipgTransactionId;

    @JsonProperty("merchantTransactionId")
    private String merchantTransactionId;

    @JsonProperty("requestType")
    private String requestType;

    @JsonProperty("transactionAmount")
    private TransactionAmount transactionAmount;

    @JsonProperty("order")
    private Order order;

    @JsonProperty("paymentMethod")
    private PaymentMethod paymentMethod;

    @JsonProperty("storedCredentials")
    private StoredCredentials storedCredentials;

    @JsonProperty("storeId")
    private String storeId;

    @JsonProperty("authenticationRequest")
    private AuthenticationRequest authenticationRequest;


    public Long getIpgTransactionId() {
        return ipgTransactionId;
    }

    public void setIpgTransactionId(Long ipgTransactionId) {
        this.ipgTransactionId = ipgTransactionId;
    }

    public String getMerchantTransactionId() {
        return merchantTransactionId;
    }

    public void setMerchantTransactionId(String merchantTransactionId) {
        this.merchantTransactionId = merchantTransactionId;
    }

    public String getRequestType() {
        return requestType;
    }

    public void setRequestType(String requestType) {
        this.requestType = requestType;
    }

    public TransactionAmount getTransactionAmount() {
        return transactionAmount;
    }

    public void setTransactionAmount(TransactionAmount transactionAmount) {
        this.transactionAmount = transactionAmount;
    }

    public Order getOrder() {
        return order;
    }

    public void setOrder(Order order) {
        this.order = order;
    }

    public PaymentMethod getPaymentMethod() {
        return paymentMethod;
    }

    public void setPaymentMethod(PaymentMethod paymentMethod) {
        this.paymentMethod = paymentMethod;
    }

    public StoredCredentials getStoredCredentials() {
        return storedCredentials;
    }

    public void setStoredCredentials(StoredCredentials storedCredentials) {
        this.storedCredentials = storedCredentials;
    }

    public String getStoreId() {
        return storeId;
    }

    public void setStoreId(String storeId) {
        this.storeId = storeId;
    }

    public AuthenticationRequest getAuthenticationRequest() {
        return authenticationRequest;
    }

    public void setAuthenticationRequest(AuthenticationRequest authenticationRequest) {
        this.authenticationRequest = authenticationRequest;
    }

    @Override
    public String toString() {
        ObjectMapper objectMapper = new ObjectMapper();
        try {
            return objectMapper.writeValueAsString(this);
        } catch (JsonProcessingException e) {
            e.printStackTrace();
            return super.toString();
        }
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PaymentTokenSaleTransactionRequest that = (PaymentTokenSaleTransactionRequest) o;
        return Objects.equals(ipgTransactionId, that.ipgTransactionId) && Objects.equals(merchantTransactionId, that.merchantTransactionId) && Objects.equals(requestType, that.requestType) && Objects.equals(transactionAmount, that.transactionAmount) && Objects.equals(order, that.order) && Objects.equals(paymentMethod, that.paymentMethod) && Objects.equals(storedCredentials, that.storedCredentials) && Objects.equals(storeId, that.storeId) && Objects.equals(authenticationRequest, that.authenticationRequest);
    }

    @Override
    public int hashCode() {
        return Objects.hash(ipgTransactionId, merchantTransactionId, requestType, transactionAmount, order, paymentMethod, storedCredentials, storeId, authenticationRequest);
    }
}

==> sdd.fiservapi.client-0.1.21-sources.jar: ar/com/sdd/fiservapi/io/PaymentTokenSaleTransactionRequest.java <==
package ar.com.sdd.fiservapi.io;

import ar.com.sdd.fiservapi.io.secure3d.AuthenticationRequest;
import ar.com.sdd.fiservapi.model.Order;
import ar.com.sdd.fiservapi.model.StoredCredentials;
import ar.com.sdd.fiservapi.model.TransactionAmount;
import ar.com.sdd.fiservapi.model.PaymentMethod;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.Serializable;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class PaymentTokenSaleTransactionRequest implements Serializable {

    @JsonProperty("ipgTransactionId")
    private Long ipgTransactionId;

    @JsonProperty("merchantTransactionId")
    private String merchantTransactionId;

    @JsonProperty("requestType")
    private String requestType;

    @JsonProperty("transactionAmount")
    private TransactionAmount transactionAmount;

    @JsonProperty("order")
    private Order order;

    @JsonProperty("paymentMethod")
    private PaymentMethod paymentMethod;

    @JsonProperty("storedCredentials")
    private StoredCredentials storedCredentials;

    @JsonProperty("storeId")
    private String storeId;

    @JsonProperty("authenticationRequest")
    private AuthenticationRequest authenticationRequest;


    public Long getIpgTransactionId() {
        return ipgTransactionId;
    }

    public void setIpgTransactionId(Long ipgTransactionId) {
        this.ipgTransactionId = ipgTransactionId;
    }

    public String getMerchantTransactionId() {
        return merchantTransactionId;
    }

    public void setMerchantTransactionId(String merchantTransactionId) {
        this.merchantTransactionId = merchantTransactionId;
    }

    public String getRequestType() {
        return requestType;
    }

    public void setRequestType(String requestType) {
        this.requestType = requestType;
    }

    public TransactionAmount getTransactionAmount() {
        return transactionAmount;
    }

    public void setTransactionAmount(TransactionAmount transactionAmount) {
        this.transactionAmount = transactionAmount;
    }

    public Order getOrder() {
        return order;
    }

    public void setOrder(Order order) {
        this.order = order;
    }

    public PaymentMethod getPaymentMethod() {
        return paymentMethod;
    }

    public void setPaymentMethod(PaymentMethod paymentMethod) {
        this.paymentMethod = paymentMethod;
    }

    public StoredCredentials getStoredCredentials() {
        return storedCredentials;
    }

    public void setStoredCredentials(StoredCredentials storedCredentials) {
        this.storedCredentials = storedCredentials;
    }

    public String getStoreId() {
        return storeId;
    }

    public void setStoreId(String storeId) {
        this.storeId = storeId;
    }

    public AuthenticationRequest getAuthenticationRequest() {
        return authenticationRequest;
    }

    public void setAuthenticationRequest(AuthenticationRequest authenticationRequest) {
        this.authenticationRequest = authenticationRequest;
    }

    @Override
    public String toString() {
        ObjectMapper objectMapper = new ObjectMapper();
        try {
            return objectMapper.writeValueAsString(this);
        } catch (JsonProcessingException e) {
            e.printStackTrace();
            return super.toString();
        }
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PaymentTokenSaleTransactionRequest that = (PaymentTokenSaleTransactionRequest) o;
        return Objects.equals(ipgTransactionId, that.ipgTransactionId) && Objects.equals(merchantTransactionId, that.merchantTransactionId) && Objects.equals(requestType, that.requestType) && Objects.equals(transactionAmount, that.transactionAmount) && Objects.equals(order, that.order) && Objects.equals(paymentMethod, that.paymentMethod) && Objects.equals(storedCredentials, that.storedCredentials) && Objects.equals(storeId, that.storeId) && Objects.equals(authenticationRequest, that.authenticationRequest);
    }

    @Override
    public int hashCode() {
        return Objects.hash(ipgTransactionId, merchantTransactionId, requestType, transactionAmount, order, paymentMethod, storedCredentials, storeId, authenticationRequest);
    }
}
